@@ -1,5 +1,5 @@
 package Linux::FD::Pid;
-$Linux::FD::Pid::VERSION = '0.001';
+$Linux::FD::Pid::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -23,7 +23,7 @@ Linux::FD::Pid - PID file descriptors
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -37,12 +37,18 @@ version 0.001
 
 This creates a pidfd file descriptor that can be used to await the termination of a process. This provides an alternative to using C<SIGCHLD>, and has the advantage that the file descriptor may be monitored by select, poll, and epoll.
 
-Note that it doesn't (and for now can't) do the actual waiting, one still needs C<waitpid> for that.
-
 =head2 send($signo)
 
 This sends a signal to the process.
 
+=head2 wait($flags = WEXITED)
+
+This waits for the process to end. It's only allowed to be child of the current process. It takes a flags argument like `waitpid`, the constants for this from the L<POSIX|POSIX> module can be used for this.
+
+=head2 get_handle($fd)
+
+This duplicates a handle from another process. Permission to duplicate another process's file descriptor is governed by a ptrace access mode C<PTRACE_MODE_ATTACH_REALCREDS> check.
+
 =head1 AUTHOR
 
 Leon Timmermans <leont@cpan.org>
